%global srcname tifffile

Name:           python-%{srcname}
Version:        2022.2.9
Release:        %mkrel 2
Summary:        Read and write TIFF(r) files
Group:          Development/Python
License:        BSD
URL:            https://www.lfd.uci.edu/~gohlke/
Source0:        %{pypi_source}

BuildArch:      noarch

%description
Tifffile is a Python library to:
 * store numpy arrays in TIFF (Tagged Image File Format) files, and
 * read image and metadata from TIFF-like files used in bioimaging.

%package -n python3-%{srcname}
Summary:        Read and write TIFF(r) files
Group:          Development/Python
%{?python_provide:%python_provide python3-%{srcname}}
BuildRequires:  python3-devel
BuildRequires:  python3-setuptools
# Testing
BuildRequires:  python3-pytest
BuildRequires:  python3-numpy
BuildRequires:  python3dist(fsspec)
BuildRequires:  python3dist(lxml)

%description -n python3-%{srcname}
Tifffile is a Python library to:
 * store numpy arrays in TIFF (Tagged Image File Format) files, and
 * read image and metadata from TIFF-like files used in bioimaging.

%prep
%autosetup -n %{srcname}-%{version}

sed -i -e "1d" tifffile/lsm2bin.py
sed -i 's/\r$//' README.rst

%build
%py3_build

%install
%py3_install

%check
export PYTHONDONTWRITEBYTECODE=1
export PYTEST_ADDOPTS='-p no:cacheprovider'
export PYTHONPATH="${PYTHONPATH:-%{buildroot}%{python3_sitearch}:%{buildroot}%{python3_sitelib}}"
# 7 tests fail out of 1000 
# these tests require network or additional packages not in Fedora
pytest-%{python3_version} -v tests \
 --deselect=tests/test_tifffile.py::test_issue_infinite_loop \
 --deselect=tests/test_tifffile.py::test_issue_jpeg_ia \
 --deselect=tests/test_tifffile.py::test_func_pformat_xml \
 --deselect=tests/test_tifffile.py::test_filehandle_seekable \
 --deselect=tests/test_tifffile.py::test_read_cfa \
 --deselect=tests/test_tifffile.py::test_read_tiles \
 --deselect=tests/test_tifffile.py::test_write_cfa \
 --deselect=tests/test_tifffile.py::test_write_volume_png \
 --deselect=tests/test_tifffile.py::test_class_omexml \
 --deselect=tests/test_tifffile.py::test_write_ome \
 --deselect=tests/test_tifffile.py::test_write_3gb \
 --deselect=tests/test_tifffile.py::test_write_bigtiff \
 --deselect=tests/test_tifffile.py::test_write_imagej_raw
# deselect the last three because they use large amounts of memory and time

%files -n python3-%{srcname}
%license LICENSE
%doc README.rst
%{_bindir}/lsm2bin
%{_bindir}/tiffcomment
%{_bindir}/tifffile
%{_bindir}/tiff2fsspec
%{python3_sitelib}/%{srcname}-*.egg-info/
%{python3_sitelib}/%{srcname}/


%changelog
* Tue Mar 29 2022 umeabot <umeabot> 2022.2.9-2.mga9
+ Revision: 1832827
- Mageia 9 Mass Rebuild

* Wed Feb 23 2022 mrambo3501 <mrambo3501> 2022.2.9-1.mga9
+ Revision: 1783584
- version 2022.2.9
- rebuild for python-3.10

* Tue Apr 20 2021 daviddavid <daviddavid> 2021.4.8-1.mga9
+ Revision: 1717510
- new version: 2021.4.8

* Tue Apr 20 2021 daviddavid <daviddavid> 2020.7.4-1.mga9
+ Revision: 1717307
- initial package python-tifffile

